module ADC_core
(
input				clk,		//系统时钟
input				rst_n,  	//系统复位，低有效
output				adc_cs,		//SPI总线CS
output				adc_clk,	//SPI总线SCK
input				adc_dat,	//SPI总线SDA
output				adc_done,	//ADC采样完成标志
output	wire unsigned [7:0]	adc_data	//ADC采样数据
);

logic clk_25m;
logic unsigned [7:0] count_1m;

always_ff@(posedge clk, negedge rst_n)
begin : CLK_1M_DIVIDE
    if(~rst_n) begin
      count_1m <= 0;
    end else if(count_1m >= 8'd3)begin
		count_1m <= 0;
	end else begin
		count_1m <= count_1m + 1'b1;
	end
end : CLK_1M_DIVIDE


always_ff@(posedge clk, negedge rst_n)
begin : CLK_1M_GEN
    if(~rst_n) begin
      clk_25m <= 1'b0;
    end else if(count_1m <= 8'd2-1)begin
		clk_25m <= 1'b0;
	end else begin
		clk_25m <= 1'b1;
	end
end : CLK_1M_GEN



logic unsigned [7:0] cnt; //计数器
always_ff @(posedge clk_25m , negedge rst_n)
	if(!rst_n) cnt <= 1'b0;
	else if(cnt >= 8'd34) cnt <= 1'b0;
	else cnt <= cnt + 1'b1;
	
logic  adc_cs1;
logic  adc_clk1;
logic  unsigned [7:0] adc_data1;
//logic  adc_dat1;
logic  adc_done1;
parameter HIGH = 1'b1;
parameter LOW  = 1'b0;
	
assign  adc_cs = adc_cs1;
assign  adc_clk = adc_clk1;
assign  adc_data = adc_data1;//adc_data1;
//assign  adc_dat1 = adc_dat;
assign  adc_done = adc_done1;
 
logic unsigned [7:0] data;

always_ff @(posedge clk_25m , negedge rst_n)
	if(!rst_n) begin
		adc_cs1 <= HIGH; adc_clk1 <= HIGH;
	end else case(cnt)
		8'd0 :  begin adc_cs1 <= HIGH; adc_clk1 <= HIGH; end
		8'd1 :  begin adc_cs1 <= LOW;  adc_clk1 <= HIGH; end
		8'd2,8'd4,8'd6,8'd8,8'd10,8'd12,8'd14,8'd16,
		8'd18,8'd20,8'd22,8'd24,8'd26,8'd28,8'd30,8'd32:	
				begin adc_cs1 <= LOW;  adc_clk1 <= LOW;  end
		8'd3 :  begin adc_cs1 <= LOW;  adc_clk1 <= HIGH; end //0
		8'd5 :  begin adc_cs1 <= LOW;  adc_clk1 <= HIGH; end //1
		8'd7 :  begin adc_cs1 <= LOW;  adc_clk1 <= HIGH; end //2
		8'd9 :  begin adc_cs1 <= LOW;  adc_clk1 <= HIGH; data[7] <= adc_dat; end //3
		8'd11 : begin adc_cs1 <= LOW;  adc_clk1 <= HIGH; data[6] <= adc_dat; end //4
		8'd13 : begin adc_cs1 <= LOW;  adc_clk1 <= HIGH; data[5] <= adc_dat; end //5
		8'd15 : begin adc_cs1 <= LOW;  adc_clk1 <= HIGH; data[4] <= adc_dat; end //6
		8'd17 : begin adc_cs1 <= LOW;  adc_clk1 <= HIGH; data[3] <= adc_dat; end //7
		8'd19 : begin adc_cs1 <= LOW;  adc_clk1 <= HIGH; data[2] <= adc_dat; end //8
		8'd21 : begin adc_cs1 <= LOW;  adc_clk1 <= HIGH; data[1] <= adc_dat; end //9
		8'd23 : begin adc_cs1 <= LOW;  adc_clk1 <= HIGH; data[0] <= adc_dat; end //10
		8'd25 : begin adc_cs1 <= LOW;  adc_clk1 <= HIGH; adc_data1 <= data; end //11
		8'd27 : begin adc_cs1 <= LOW;  adc_clk1 <= HIGH; adc_done1 <= HIGH; end //12
		8'd29 : begin adc_cs1 <= LOW;  adc_clk1 <= HIGH; adc_done1 <= LOW; end //13
		8'd31 : begin adc_cs1 <= LOW;  adc_clk1 <= HIGH; end //14
		8'd33 : begin adc_cs1 <= LOW;  adc_clk1 <= HIGH; end //15
		8'd34 : begin adc_cs1 <= HIGH;  adc_clk1 <= HIGH; end
		default : begin adc_cs1 <= HIGH;  adc_clk1 <= HIGH;  end
	endcase
	
endmodule